from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.command_progress import CommandProgress
    from ..models.device_reported_configuration_state import DeviceReportedConfigurationState
    from ..models.device_ros_state import DeviceRosState
    from ..models.device_state_env import DeviceStateEnv
    from ..models.hw_info import HwInfo
    from ..models.on_demand_state import OnDemandState


T = TypeVar("T", bound="DeviceState")


@attr.s(auto_attribs=True)
class DeviceState:
    """
    Attributes:
        agent_version (Union[Unset, None, str]):
        reported_configuration (Union[Unset, None, DeviceReportedConfigurationState]):
        hw_info (Union[Unset, None, HwInfo]):
        ros (Union[Unset, None, DeviceRosState]):
        env (Union[Unset, None, DeviceStateEnv]):
        ota_enabled (Union[Unset, None, bool]):
        on_demand (Union[Unset, None, OnDemandState]):
        command_progress (Union[Unset, None, List['CommandProgress']]):
        version (Union[Unset, None, str]):
    """

    agent_version: Union[Unset, None, str] = UNSET
    reported_configuration: Union[Unset, None, "DeviceReportedConfigurationState"] = UNSET
    hw_info: Union[Unset, None, "HwInfo"] = UNSET
    ros: Union[Unset, None, "DeviceRosState"] = UNSET
    env: Union[Unset, None, "DeviceStateEnv"] = UNSET
    ota_enabled: Union[Unset, None, bool] = UNSET
    on_demand: Union[Unset, None, "OnDemandState"] = UNSET
    command_progress: Union[Unset, None, List["CommandProgress"]] = UNSET
    version: Union[Unset, None, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        agent_version = self.agent_version
        reported_configuration: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.reported_configuration, Unset):
            reported_configuration = self.reported_configuration.to_dict() if self.reported_configuration else None

        hw_info: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.hw_info, Unset):
            hw_info = self.hw_info.to_dict() if self.hw_info else None

        ros: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.ros, Unset):
            ros = self.ros.to_dict() if self.ros else None

        env: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.env, Unset):
            env = self.env.to_dict() if self.env else None

        ota_enabled = self.ota_enabled
        on_demand: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.on_demand, Unset):
            on_demand = self.on_demand.to_dict() if self.on_demand else None

        command_progress: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.command_progress, Unset):
            if self.command_progress is None:
                command_progress = None
            else:
                command_progress = []
                for command_progress_item_data in self.command_progress:
                    command_progress_item = command_progress_item_data.to_dict()

                    command_progress.append(command_progress_item)

        version = self.version

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if agent_version is not UNSET:
            field_dict["agentVersion"] = agent_version
        if reported_configuration is not UNSET:
            field_dict["reportedConfiguration"] = reported_configuration
        if hw_info is not UNSET:
            field_dict["hwInfo"] = hw_info
        if ros is not UNSET:
            field_dict["ros"] = ros
        if env is not UNSET:
            field_dict["env"] = env
        if ota_enabled is not UNSET:
            field_dict["otaEnabled"] = ota_enabled
        if on_demand is not UNSET:
            field_dict["onDemand"] = on_demand
        if command_progress is not UNSET:
            field_dict["commandProgress"] = command_progress
        if version is not UNSET:
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.command_progress import CommandProgress
        from ..models.device_reported_configuration_state import DeviceReportedConfigurationState
        from ..models.device_ros_state import DeviceRosState
        from ..models.device_state_env import DeviceStateEnv
        from ..models.hw_info import HwInfo
        from ..models.on_demand_state import OnDemandState

        d = src_dict.copy()
        agent_version = d.pop("agentVersion", UNSET)

        _reported_configuration = d.pop("reportedConfiguration", UNSET)
        reported_configuration: Union[Unset, None, DeviceReportedConfigurationState]
        if _reported_configuration is None:
            reported_configuration = None
        elif isinstance(_reported_configuration, Unset):
            reported_configuration = UNSET
        else:
            reported_configuration = DeviceReportedConfigurationState.from_dict(_reported_configuration)

        _hw_info = d.pop("hwInfo", UNSET)
        hw_info: Union[Unset, None, HwInfo]
        if _hw_info is None:
            hw_info = None
        elif isinstance(_hw_info, Unset):
            hw_info = UNSET
        else:
            hw_info = HwInfo.from_dict(_hw_info)

        _ros = d.pop("ros", UNSET)
        ros: Union[Unset, None, DeviceRosState]
        if _ros is None:
            ros = None
        elif isinstance(_ros, Unset):
            ros = UNSET
        else:
            ros = DeviceRosState.from_dict(_ros)

        _env = d.pop("env", UNSET)
        env: Union[Unset, None, DeviceStateEnv]
        if _env is None:
            env = None
        elif isinstance(_env, Unset):
            env = UNSET
        else:
            env = DeviceStateEnv.from_dict(_env)

        ota_enabled = d.pop("otaEnabled", UNSET)

        _on_demand = d.pop("onDemand", UNSET)
        on_demand: Union[Unset, None, OnDemandState]
        if _on_demand is None:
            on_demand = None
        elif isinstance(_on_demand, Unset):
            on_demand = UNSET
        else:
            on_demand = OnDemandState.from_dict(_on_demand)

        command_progress = []
        _command_progress = d.pop("commandProgress", UNSET)
        for command_progress_item_data in _command_progress or []:
            command_progress_item = CommandProgress.from_dict(command_progress_item_data)

            command_progress.append(command_progress_item)

        version = d.pop("version", UNSET)

        device_state = cls(
            agent_version=agent_version,
            reported_configuration=reported_configuration,
            hw_info=hw_info,
            ros=ros,
            env=env,
            ota_enabled=ota_enabled,
            on_demand=on_demand,
            command_progress=command_progress,
            version=version,
        )

        device_state.additional_properties = d
        return device_state

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.scope_filter import ScopeFilter


T = TypeVar("T", bound="Share")


@attr.s(auto_attribs=True)
class Share:
    """
    Attributes:
        time (datetime.datetime):
        organization_id (Union[Unset, str]):
        user_id (Union[Unset, str]):
        code (Union[Unset, str]):
        scope (Optional[ScopeFilter]):
        expiration (Union[Unset, datetime.datetime]):
        message (Union[Unset, str]):
        user_name (Union[Unset, str]):
        channel_id (Union[Unset, str]):
        delegate_teleop (Union[Unset, bool]):
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
    """

    time: datetime.datetime
    scope: Optional["ScopeFilter"]
    organization_id: Union[Unset, str] = UNSET
    user_id: Union[Unset, str] = UNSET
    code: Union[Unset, str] = UNSET
    expiration: Union[Unset, datetime.datetime] = UNSET
    message: Union[Unset, str] = UNSET
    user_name: Union[Unset, str] = UNSET
    channel_id: Union[Unset, str] = UNSET
    delegate_teleop: Union[Unset, bool] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        time = self.time.isoformat()

        organization_id = self.organization_id
        user_id = self.user_id
        code = self.code
        scope = self.scope.to_dict() if self.scope else None

        expiration: Union[Unset, str] = UNSET
        if not isinstance(self.expiration, Unset):
            expiration = self.expiration.isoformat()

        message = self.message
        user_name = self.user_name
        channel_id = self.channel_id
        delegate_teleop = self.delegate_teleop
        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "time": time,
                "scope": scope,
            }
        )
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if user_id is not UNSET:
            field_dict["userId"] = user_id
        if code is not UNSET:
            field_dict["code"] = code
        if expiration is not UNSET:
            field_dict["expiration"] = expiration
        if message is not UNSET:
            field_dict["message"] = message
        if user_name is not UNSET:
            field_dict["userName"] = user_name
        if channel_id is not UNSET:
            field_dict["channelId"] = channel_id
        if delegate_teleop is not UNSET:
            field_dict["delegateTeleop"] = delegate_teleop
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.scope_filter import ScopeFilter

        d = src_dict.copy()
        time = isoparse(d.pop("time"))

        organization_id = d.pop("organizationId", UNSET)

        user_id = d.pop("userId", UNSET)

        code = d.pop("code", UNSET)

        _scope = d.pop("scope")
        scope: Optional[ScopeFilter]
        if _scope is None:
            scope = None
        else:
            scope = ScopeFilter.from_dict(_scope)

        _expiration = d.pop("expiration", UNSET)
        expiration: Union[Unset, datetime.datetime]
        if isinstance(_expiration, Unset):
            expiration = UNSET
        else:
            expiration = isoparse(_expiration)

        message = d.pop("message", UNSET)

        user_name = d.pop("userName", UNSET)

        channel_id = d.pop("channelId", UNSET)

        delegate_teleop = d.pop("delegateTeleop", UNSET)

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        share = cls(
            time=time,
            organization_id=organization_id,
            user_id=user_id,
            code=code,
            scope=scope,
            expiration=expiration,
            message=message,
            user_name=user_name,
            channel_id=channel_id,
            delegate_teleop=delegate_teleop,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
        )

        share.additional_properties = d
        return share

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="SsoGroupNameToTeamMapping")


@attr.s(auto_attribs=True)
class SsoGroupNameToTeamMapping:
    """
    Attributes:
        sso_group_name (str):
        team_id (str):
    """

    sso_group_name: str
    team_id: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sso_group_name = self.sso_group_name
        team_id = self.team_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "ssoGroupName": sso_group_name,
                "teamId": team_id,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        sso_group_name = d.pop("ssoGroupName")

        team_id = d.pop("teamId")

        sso_group_name_to_team_mapping = cls(
            sso_group_name=sso_group_name,
            team_id=team_id,
        )

        sso_group_name_to_team_mapping.additional_properties = d
        return sso_group_name_to_team_mapping

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/agent/v1/agent.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/agent/v1/agent.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import datapoint_pb2 as protos_dot_model_dot_v1_dot_datapoint__pb2
from formant.protos.model.v1 import intervention_pb2 as protos_dot_model_dot_v1_dot_intervention__pb2
from formant.protos.model.v1 import commands_pb2 as protos_dot_model_dot_v1_dot_commands__pb2
from formant.protos.model.v1 import config_pb2 as protos_dot_model_dot_v1_dot_config__pb2
from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2
from formant.protos.model.v1 import event_pb2 as protos_dot_model_dot_v1_dot_event__pb2
from formant.protos.model.v1 import health_pb2 as protos_dot_model_dot_v1_dot_health__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bprotos/agent/v1/agent.proto\x12\x08v1.agent\x1a\x1fprotos/model/v1/datapoint.proto\x1a\"protos/model/v1/intervention.proto\x1a\x1eprotos/model/v1/commands.proto\x1a\x1cprotos/model/v1/config.proto\x1a\x1aprotos/model/v1/math.proto\x1a\x1bprotos/model/v1/event.proto\x1a\x1cprotos/model/v1/health.proto\"S\n\'PostGenericAPIUnbufferedRequestResponse\x12\x12\n\nstatusCode\x18\x01 \x01(\r\x12\x14\n\x0cresponseBody\x18\x02 \x01(\t\"\x1f\n\x1dPostGenericAPIRequestResponse\"\x14\n\x12StreamDataResponse\"\x12\n\x10PostDataResponse\"P\n\rPostDataError\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\r\x12\x11\n\tretryable\x18\x03 \x01(\x08\x12\x0f\n\x07message\x18\x04 \x01(\t\"?\n\x14PostDataMultiRequest\x12\'\n\ndatapoints\x18\x01 \x03(\x0b\x32\x13.v1.model.Datapoint\"\x17\n\x15PostDataMultiResponse\"=\n\x12PostDataMultiError\x12\'\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x17.v1.agent.PostDataError\"+\n\x1dGetInterventionRequestRequest\x12\n\n\x02id\x18\x01 \x01(\t\"4\n\x1eGetInterventionResponseRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\" \n\x1eGetStreamsConfigurationRequest\"Q\n\x1fGetStreamsConfigurationResponse\x12.\n\x07streams\x18\x01 \x03(\x0b\x32\x1d.v1.model.StreamConfiguration\"$\n\"GetApplicationConfigurationRequest\"`\n#GetApplicationConfigurationResponse\x12\x39\n\rconfiguration\x18\x01 \x01(\x0b\x32\".v1.model.ApplicationConfiguration\"\x1a\n\x18GetConfigBlobDataRequest\"B\n\x19GetConfigBlobDataResponse\x12%\n\tblob_data\x18\x01 \x01(\x0b\x32\x12.v1.model.BlobData\"\x1e\n\x1cGetAgentConfigurationRequest\"T\n\x1dGetAgentConfigurationResponse\x12\x33\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1c.v1.model.AgentConfiguration\"\x1a\n\x18GetBufferMetadataRequest\"h\n\x16QueryDatapointsRequest\x12\x13\n\x0bstream_name\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\r\x12\x0e\n\x06offset\x18\x05 \x01(\r\"?\n\x17QueryDatapointsResponse\x12$\n\x07results\x18\x01 \x03(\x0b\x32\x13.v1.model.Datapoint\"O\n\x12QueryEventsRequest\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\r\x12\x0e\n\x06offset\x18\x04 \x01(\r\"7\n\x13QueryEventsResponse\x12 \n\x07results\x18\x01 \x03(\x0b\x32\x0f.v1.model.Event\"J\n\x19GetBufferMetadataResponse\x12-\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32\x18.v1.model.BufferMetadata\"\x0f\n\rHealthRequest\"\x10\n\x0eHealthResponse\"2\n\x18GetCommandRequestRequest\x12\x16\n\x0e\x63ommand_filter\x18\x01 \x03(\t\"F\n\x19GetCommandRequestResponse\x12)\n\x07request\x18\x01 \x01(\x0b\x32\x18.v1.model.CommandRequest\"I\n\x1aSendCommandResponseRequest\x12+\n\x08response\x18\x01 \x01(\x0b\x32\x19.v1.model.CommandResponse\"\x1d\n\x1bSendCommandResponseResponse\"8\n\x1eGetCommandRequestStreamRequest\x12\x16\n\x0e\x63ommand_filter\x18\x01 \x03(\t\"L\n\x1fGetCommandRequestStreamResponse\x12)\n\x07request\x18\x01 \x01(\x0b\x32\x18.v1.model.CommandRequest\":\n!GetTeleopControlDataStreamRequest\x12\x15\n\rstream_filter\x18\x01 \x03(\t\"[\n\"GetTeleopControlDataStreamResponse\x12\x35\n\x11\x63ontrol_datapoint\x18\x01 \x01(\x0b\x32\x1a.v1.model.ControlDatapoint\"!\n\x1fGetTeleopHeartbeatStreamRequest\"`\n GetTeleopHeartbeatStreamResponse\x12\x0f\n\x07peer_id\x18\x01 \x01(\t\x12\x15\n\ris_disconnect\x18\x02 \x01(\x08\x12\x14\n\x0csession_type\x18\x03 \x01(\t\":\n!GetTelemetryListenerStreamRequest\x12\x15\n\rstream_filter\x18\x01 \x03(\t\"L\n\"GetTelemetryListenerStreamResponse\x12&\n\tdatapoint\x18\x01 \x01(\x0b\x32\x13.v1.model.Datapoint\"\x1c\n\x1aPostTransformFrameResponse\"#\n\x15SetBaseFrameIDRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x18\n\x16SetBaseFrameIDResponse\"\x1b\n\x19\x43learTransformTreeRequest\"\x1c\n\x1a\x43learTransformTreeResponse\"4\n\x12\x43reateEventRequest\x12\x1e\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x0f.v1.model.Event\"\x15\n\x13\x43reateEventResponse\"%\n\x10\x43reateEventError\x12\x11\n\tretryable\x18\x01 \x01(\x08\"\x16\n\x14GetTeleopInfoRequest\"1\n\x15GetTeleopInfoResponse\x12\x18\n\x10\x63onnection_count\x18\x01 \x01(\r\"\'\n\x16PostLanRtcOfferRequest\x12\r\n\x05offer\x18\x01 \x01(\t\")\n\x17PostLanRtcOfferResponse\x12\x0e\n\x06\x61nswer\x18\x01 \x01(\t\"G\n\x1eSendOnCustomDataChannelRequest\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"!\n\x1fSendOnCustomDataChannelResponse\"G\n(GetCustomDataChannelMessageStreamRequest\x12\x1b\n\x13\x63hannel_name_filter\x18\x01 \x03(\t\"c\n)GetCustomDataChannelMessageStreamResponse\x12\x0f\n\x07peer_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x32\xa2\x17\n\x05\x41gent\x12\x43\n\nStreamData\x12\x13.v1.model.Datapoint\x1a\x1c.v1.agent.StreamDataResponse\"\x00(\x01\x12=\n\x08PostData\x12\x13.v1.model.Datapoint\x1a\x1a.v1.agent.PostDataResponse\"\x00\x12R\n\rPostDataMulti\x12\x1e.v1.agent.PostDataMultiRequest\x1a\x1f.v1.agent.PostDataMultiResponse\"\x00\x12{\n\x1aGetTeleopControlDataStream\x12+.v1.agent.GetTeleopControlDataStreamRequest\x1a,.v1.agent.GetTeleopControlDataStreamResponse\"\x00\x30\x01\x12u\n\x18GetTeleopHeartbeatStream\x12).v1.agent.GetTeleopHeartbeatStreamRequest\x1a*.v1.agent.GetTeleopHeartbeatStreamResponse\"\x00\x30\x01\x12{\n\x1aGetTelemetryListenerStream\x12+.v1.agent.GetTelemetryListenerStreamRequest\x1a,.v1.agent.GetTelemetryListenerStreamResponse\"\x00\x30\x01\x12\x90\x01\n!GetCustomDataChannelMessageStream\x12\x32.v1.agent.GetCustomDataChannelMessageStreamRequest\x1a\x33.v1.agent.GetCustomDataChannelMessageStreamResponse\"\x00\x30\x01\x12L\n\x0b\x43reateEvent\x12\x1c.v1.agent.CreateEventRequest\x1a\x1d.v1.agent.CreateEventResponse\"\x00\x12[\n\x19\x43reateInterventionRequest\x12\x1d.v1.model.InterventionRequest\x1a\x1d.v1.model.InterventionRequest\"\x00\x12\x62\n\x16GetInterventionRequest\x12\'.v1.agent.GetInterventionRequestRequest\x1a\x1d.v1.model.InterventionRequest\"\x00\x12\x65\n\x17GetInterventionResponse\x12(.v1.agent.GetInterventionResponseRequest\x1a\x1e.v1.model.InterventionResponse\"\x00\x12p\n\x17GetStreamsConfiguration\x12(.v1.agent.GetStreamsConfigurationRequest\x1a).v1.agent.GetStreamsConfigurationResponse\"\x00\x12|\n\x1bGetApplicationConfiguration\x12,.v1.agent.GetApplicationConfigurationRequest\x1a-.v1.agent.GetApplicationConfigurationResponse\"\x00\x12^\n\x11GetConfigBlobData\x12\".v1.agent.GetConfigBlobDataRequest\x1a#.v1.agent.GetConfigBlobDataResponse\"\x00\x12j\n\x15GetAgentConfiguration\x12&.v1.agent.GetAgentConfigurationRequest\x1a\'.v1.agent.GetAgentConfigurationResponse\"\x00\x12^\n\x11GetBufferMetadata\x12\".v1.agent.GetBufferMetadataRequest\x1a#.v1.agent.GetBufferMetadataResponse\"\x00\x12X\n\x0fQueryDatapoints\x12 .v1.agent.QueryDatapointsRequest\x1a!.v1.agent.QueryDatapointsResponse\"\x00\x12L\n\x0bQueryEvents\x12\x1c.v1.agent.QueryEventsRequest\x1a\x1d.v1.agent.QueryEventsResponse\"\x00\x12=\n\x06Health\x12\x17.v1.agent.HealthRequest\x1a\x18.v1.agent.HealthResponse\"\x00\x12^\n\x11GetCommandRequest\x12\".v1.agent.GetCommandRequestRequest\x1a#.v1.agent.GetCommandRequestResponse\"\x00\x12r\n\x17GetCommandRequestStream\x12(.v1.agent.GetCommandRequestStreamRequest\x1a).v1.agent.GetCommandRequestStreamResponse\"\x00\x30\x01\x12\x64\n\x13SendCommandResponse\x12$.v1.agent.SendCommandResponseRequest\x1a%.v1.agent.SendCommandResponseResponse\"\x00\x12V\n\x12PostTransformFrame\x12\x18.v1.model.TransformFrame\x1a$.v1.agent.PostTransformFrameResponse\"\x00\x12U\n\x0eSetBaseFrameID\x12\x1f.v1.agent.SetBaseFrameIDRequest\x1a .v1.agent.SetBaseFrameIDResponse\"\x00\x12\x61\n\x12\x43learTransformTree\x12#.v1.agent.ClearTransformTreeRequest\x1a$.v1.agent.ClearTransformTreeResponse\"\x00\x12R\n\rGetTeleopInfo\x12\x1e.v1.agent.GetTeleopInfoRequest\x1a\x1f.v1.agent.GetTeleopInfoResponse\"\x00\x12X\n\x0fPostLanRtcOffer\x12 .v1.agent.PostLanRtcOfferRequest\x1a!.v1.agent.PostLanRtcOfferResponse\"\x00\x12p\n\x17SendOnCustomDataChannel\x12(.v1.agent.SendOnCustomDataChannelRequest\x1a).v1.agent.SendOnCustomDataChannelResponse\"\x00\x12\x61\n\x15PostGenericAPIRequest\x12\x1d.v1.model.GenericAPIDatapoint\x1a\'.v1.agent.PostGenericAPIRequestResponse\"\x00\x12u\n\x1fPostGenericAPIUnbufferedRequest\x12\x1d.v1.model.GenericAPIDatapoint\x1a\x31.v1.agent.PostGenericAPIUnbufferedRequestResponse\"\x00\x42+Z)github.com/FormantIO/genproto/go/v1/agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.agent.v1.agent_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/agent'
  _globals['_POSTGENERICAPIUNBUFFEREDREQUESTRESPONSE']._serialized_start=259
  _globals['_POSTGENERICAPIUNBUFFEREDREQUESTRESPONSE']._serialized_end=342
  _globals['_POSTGENERICAPIREQUESTRESPONSE']._serialized_start=344
  _globals['_POSTGENERICAPIREQUESTRESPONSE']._serialized_end=375
  _globals['_STREAMDATARESPONSE']._serialized_start=377
  _globals['_STREAMDATARESPONSE']._serialized_end=397
  _globals['_POSTDATARESPONSE']._serialized_start=399
  _globals['_POSTDATARESPONSE']._serialized_end=417
  _globals['_POSTDATAERROR']._serialized_start=419
  _globals['_POSTDATAERROR']._serialized_end=499
  _globals['_POSTDATAMULTIREQUEST']._serialized_start=501
  _globals['_POSTDATAMULTIREQUEST']._serialized_end=564
  _globals['_POSTDATAMULTIRESPONSE']._serialized_start=566
  _globals['_POSTDATAMULTIRESPONSE']._serialized_end=589
  _globals['_POSTDATAMULTIERROR']._serialized_start=591
  _globals['_POSTDATAMULTIERROR']._serialized_end=652
  _globals['_GETINTERVENTIONREQUESTREQUEST']._serialized_start=654
  _globals['_GETINTERVENTIONREQUESTREQUEST']._serialized_end=697
  _globals['_GETINTERVENTIONRESPONSEREQUEST']._serialized_start=699
  _globals['_GETINTERVENTIONRESPONSEREQUEST']._serialized_end=751
  _globals['_GETSTREAMSCONFIGURATIONREQUEST']._serialized_start=753
  _globals['_GETSTREAMSCONFIGURATIONREQUEST']._serialized_end=785
  _globals['_GETSTREAMSCONFIGURATIONRESPONSE']._serialized_start=787
  _globals['_GETSTREAMSCONFIGURATIONRESPONSE']._serialized_end=868
  _globals['_GETAPPLICATIONCONFIGURATIONREQUEST']._serialized_start=870
  _globals['_GETAPPLICATIONCONFIGURATIONREQUEST']._serialized_end=906
  _globals['_GETAPPLICATIONCONFIGURATIONRESPONSE']._serialized_start=908
  _globals['_GETAPPLICATIONCONFIGURATIONRESPONSE']._serialized_end=1004
  _globals['_GETCONFIGBLOBDATAREQUEST']._serialized_start=1006
  _globals['_GETCONFIGBLOBDATAREQUEST']._serialized_end=1032
  _globals['_GETCONFIGBLOBDATARESPONSE']._serialized_start=1034
  _globals['_GETCONFIGBLOBDATARESPONSE']._serialized_end=1100
  _globals['_GETAGENTCONFIGURATIONREQUEST']._serialized_start=1102
  _globals['_GETAGENTCONFIGURATIONREQUEST']._serialized_end=1132
  _globals['_GETAGENTCONFIGURATIONRESPONSE']._serialized_start=1134
  _globals['_GETAGENTCONFIGURATIONRESPONSE']._serialized_end=1218
  _globals['_GETBUFFERMETADATAREQUEST']._serialized_start=1220
  _globals['_GETBUFFERMETADATAREQUEST']._serialized_end=1246
  _globals['_QUERYDATAPOINTSREQUEST']._serialized_start=1248
  _globals['_QUERYDATAPOINTSREQUEST']._serialized_end=1352
  _globals['_QUERYDATAPOINTSRESPONSE']._serialized_start=1354
  _globals['_QUERYDATAPOINTSRESPONSE']._serialized_end=1417
  _globals['_QUERYEVENTSREQUEST']._serialized_start=1419
  _globals['_QUERYEVENTSREQUEST']._serialized_end=1498
  _globals['_QUERYEVENTSRESPONSE']._serialized_start=1500
  _globals['_QUERYEVENTSRESPONSE']._serialized_end=1555
  _globals['_GETBUFFERMETADATARESPONSE']._serialized_start=1557
  _globals['_GETBUFFERMETADATARESPONSE']._serialized_end=1631
  _globals['_HEALTHREQUEST']._serialized_start=1633
  _globals['_HEALTHREQUEST']._serialized_end=1648
  _globals['_HEALTHRESPONSE']._serialized_start=1650
  _globals['_HEALTHRESPONSE']._serialized_end=1666
  _globals['_GETCOMMANDREQUESTREQUEST']._serialized_start=1668
  _globals['_GETCOMMANDREQUESTREQUEST']._serialized_end=1718
  _globals['_GETCOMMANDREQUESTRESPONSE']._serialized_start=1720
  _globals['_GETCOMMANDREQUESTRESPONSE']._serialized_end=1790
  _globals['_SENDCOMMANDRESPONSEREQUEST']._serialized_start=1792
  _globals['_SENDCOMMANDRESPONSEREQUEST']._serialized_end=1865
  _globals['_SENDCOMMANDRESPONSERESPONSE']._serialized_start=1867
  _globals['_SENDCOMMANDRESPONSERESPONSE']._serialized_end=1896
  _globals['_GETCOMMANDREQUESTSTREAMREQUEST']._serialized_start=1898
  _globals['_GETCOMMANDREQUESTSTREAMREQUEST']._serialized_end=1954
  _globals['_GETCOMMANDREQUESTSTREAMRESPONSE']._serialized_start=1956
  _globals['_GETCOMMANDREQUESTSTREAMRESPONSE']._serialized_end=2032
  _globals['_GETTELEOPCONTROLDATASTREAMREQUEST']._serialized_start=2034
  _globals['_GETTELEOPCONTROLDATASTREAMREQUEST']._serialized_end=2092
  _globals['_GETTELEOPCONTROLDATASTREAMRESPONSE']._serialized_start=2094
  _globals['_GETTELEOPCONTROLDATASTREAMRESPONSE']._serialized_end=2185
  _globals['_GETTELEOPHEARTBEATSTREAMREQUEST']._serialized_start=2187
  _globals['_GETTELEOPHEARTBEATSTREAMREQUEST']._serialized_end=2220
  _globals['_GETTELEOPHEARTBEATSTREAMRESPONSE']._serialized_start=2222
  _globals['_GETTELEOPHEARTBEATSTREAMRESPONSE']._serialized_end=2318
  _globals['_GETTELEMETRYLISTENERSTREAMREQUEST']._serialized_start=2320
  _globals['_GETTELEMETRYLISTENERSTREAMREQUEST']._serialized_end=2378
  _globals['_GETTELEMETRYLISTENERSTREAMRESPONSE']._serialized_start=2380
  _globals['_GETTELEMETRYLISTENERSTREAMRESPONSE']._serialized_end=2456
  _globals['_POSTTRANSFORMFRAMERESPONSE']._serialized_start=2458
  _globals['_POSTTRANSFORMFRAMERESPONSE']._serialized_end=2486
  _globals['_SETBASEFRAMEIDREQUEST']._serialized_start=2488
  _globals['_SETBASEFRAMEIDREQUEST']._serialized_end=2523
  _globals['_SETBASEFRAMEIDRESPONSE']._serialized_start=2525
  _globals['_SETBASEFRAMEIDRESPONSE']._serialized_end=2549
  _globals['_CLEARTRANSFORMTREEREQUEST']._serialized_start=2551
  _globals['_CLEARTRANSFORMTREEREQUEST']._serialized_end=2578
  _globals['_CLEARTRANSFORMTREERESPONSE']._serialized_start=2580
  _globals['_CLEARTRANSFORMTREERESPONSE']._serialized_end=2608
  _globals['_CREATEEVENTREQUEST']._serialized_start=2610
  _globals['_CREATEEVENTREQUEST']._serialized_end=2662
  _globals['_CREATEEVENTRESPONSE']._serialized_start=2664
  _globals['_CREATEEVENTRESPONSE']._serialized_end=2685
  _globals['_CREATEEVENTERROR']._serialized_start=2687
  _globals['_CREATEEVENTERROR']._serialized_end=2724
  _globals['_GETTELEOPINFOREQUEST']._serialized_start=2726
  _globals['_GETTELEOPINFOREQUEST']._serialized_end=2748
  _globals['_GETTELEOPINFORESPONSE']._serialized_start=2750
  _globals['_GETTELEOPINFORESPONSE']._serialized_end=2799
  _globals['_POSTLANRTCOFFERREQUEST']._serialized_start=2801
  _globals['_POSTLANRTCOFFERREQUEST']._serialized_end=2840
  _globals['_POSTLANRTCOFFERRESPONSE']._serialized_start=2842
  _globals['_POSTLANRTCOFFERRESPONSE']._serialized_end=2883
  _globals['_SENDONCUSTOMDATACHANNELREQUEST']._serialized_start=2885
  _globals['_SENDONCUSTOMDATACHANNELREQUEST']._serialized_end=2956
  _globals['_SENDONCUSTOMDATACHANNELRESPONSE']._serialized_start=2958
  _globals['_SENDONCUSTOMDATACHANNELRESPONSE']._serialized_end=2991
  _globals['_GETCUSTOMDATACHANNELMESSAGESTREAMREQUEST']._serialized_start=2993
  _globals['_GETCUSTOMDATACHANNELMESSAGESTREAMREQUEST']._serialized_end=3064
  _globals['_GETCUSTOMDATACHANNELMESSAGESTREAMRESPONSE']._serialized_start=3066
  _globals['_GETCUSTOMDATACHANNELMESSAGESTREAMRESPONSE']._serialized_end=3165
  _globals['_AGENT']._serialized_start=3168
  _globals['_AGENT']._serialized_end=6146
# @@protoc_insertion_point(module_scope)



from formant.sdk.cloud.v2.formant_admin_api_client.models import PortForwardingSessionRecord, DatapointEvent, TeleopSessionRecordStreamType, DatapointEventSeverity, InterventionRequestInterventionType, SelectionRequestData, CommentMetadata, CommandDeliveryEventType, FocusedDatapoint, LabeledPolygon, SystemEventTags, TeleopRequestData, TaskSummaryMetadata, CommandDeliveryEventTags, TeleopSessionRecordType, CommandDeliveryEventStreamType, CommentType, DeviceOnlineEventMetadata, DeviceOnlineEventStreamType, EventQueryTypesItem, EventFilterEventTypesItem, CommentStreamType, InterventionRequestType, DatapointEventTags, DatapointEventType, EventFilterTypesItem, DeviceOfflineEventSeverity, InterventionRequestTags, SystemEventType, TaskSummaryStreamType, TaskSummaryReport, PortForwardingSessionRecordStreamType, StatefulEventTags, SystemEventStreamType, InterventionRequest, StatefulEventStreamType, StatefulEvent, CustomEventMetadata, DeviceOnlineEvent, EventExportSheetRequest, DeviceOnlineEventSeverity, EventTriggerCommand, EventQuery, EventFilterSeveritiesItem, EventSeekQueryTypesItem, TeleopSessionRecord, PhysicalRequestData, TaskSummary, EventSortOrder, InterventionRequestSeverity, TeleopSessionRecordTags, EventSeekQueryDirection, EventSeekQuerySeveritiesItem, TeleopSessionRecordMetadata, InterventionRequestMetadata, DeviceOfflineEventTags, InterventionRequestStreamType, TaskSummaryType, DeviceOnlineEventTags, StatefulEventMetadata, EventQueryEventTypesItem, CommandDeliveryEvent, DatapointEventStreamType, CustomEventTags, DeviceOfflineEvent, EventExportSheetResult, DatapointEventMetadata, CustomEvent, AnnotationType, DeviceOnlineEventType, AnnotationMetadata, StatefulEventSeverity, EventSeekQuery, StatefulEventType, EventFilter, EventHistogramEntry, EventCounts, LabelingRequestData, AnnotationStreamType, CustomEventStreamType, DeviceOfflineEventMetadata, DeviceOfflineEventType, DeviceOfflineEventStreamType, SystemEvent, PortForwardingSessionRecordMetadata, CommentTags, AnnotationTags, CustomEventType, EventSort, Comment, Label, PortForwardingSessionRecordType, EventQuerySeveritiesItem, EventSortColumn, SystemEventMetadata, Annotation, CommandDeliveryEventMetadata, EventSeekQueryEventTypesItem, TaskSummaryTags, EventHistogram, CustomEventSeverity, EventListResponse, PortForwardingSessionRecordTags
from formant.sdk.cloud.v2.formant_admin_api_client.api.event import event_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *


from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.authentication import Authentication
    from ..models.challenge import Challenge


T = TypeVar("T", bound="LoginResult")


@attr.s(auto_attribs=True)
class LoginResult:
    """
    Attributes:
        authentication (Authentication):
        challenge (Union[Unset, Challenge]):
        is_existing_user (Union[Unset, bool]):
    """

    authentication: "Authentication"
    challenge: Union[Unset, "Challenge"] = UNSET
    is_existing_user: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        authentication = self.authentication.to_dict()

        challenge: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.challenge, Unset):
            challenge = self.challenge.to_dict()

        is_existing_user = self.is_existing_user

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "authentication": authentication,
            }
        )
        if challenge is not UNSET:
            field_dict["challenge"] = challenge
        if is_existing_user is not UNSET:
            field_dict["isExistingUser"] = is_existing_user

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.authentication import Authentication
        from ..models.challenge import Challenge

        d = src_dict.copy()
        authentication = Authentication.from_dict(d.pop("authentication"))

        _challenge = d.pop("challenge", UNSET)
        challenge: Union[Unset, Challenge]
        if isinstance(_challenge, Unset):
            challenge = UNSET
        else:
            challenge = Challenge.from_dict(_challenge)

        is_existing_user = d.pop("isExistingUser", UNSET)

        login_result = cls(
            authentication=authentication,
            challenge=challenge,
            is_existing_user=is_existing_user,
        )

        login_result.additional_properties = d
        return login_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.http_integration_method import HttpIntegrationMethod
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.http_integration_basic_auth import HttpIntegrationBasicAuth
    from ..models.http_integration_no_auth import HttpIntegrationNoAuth


T = TypeVar("T", bound="HttpIntegration")


@attr.s(auto_attribs=True)
class HttpIntegration:
    """
    Attributes:
        name (str):
        url (str):
        method (HttpIntegrationMethod):
        authentication (Union['HttpIntegrationBasicAuth', 'HttpIntegrationNoAuth']):
        organization_id (Union[Unset, str]):
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
    """

    name: str
    url: str
    method: HttpIntegrationMethod
    authentication: Union["HttpIntegrationBasicAuth", "HttpIntegrationNoAuth"]
    organization_id: Union[Unset, str] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.http_integration_basic_auth import HttpIntegrationBasicAuth

        name = self.name
        url = self.url
        method = self.method.value

        authentication: Dict[str, Any]

        if isinstance(self.authentication, HttpIntegrationBasicAuth):
            authentication = self.authentication.to_dict()

        else:
            authentication = self.authentication.to_dict()

        organization_id = self.organization_id
        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "url": url,
                "method": method,
                "authentication": authentication,
            }
        )
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.http_integration_basic_auth import HttpIntegrationBasicAuth
        from ..models.http_integration_no_auth import HttpIntegrationNoAuth

        d = src_dict.copy()
        name = d.pop("name")

        url = d.pop("url")

        method = HttpIntegrationMethod(d.pop("method"))

        def _parse_authentication(data: object) -> Union["HttpIntegrationBasicAuth", "HttpIntegrationNoAuth"]:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                authentication_type_0 = HttpIntegrationBasicAuth.from_dict(data)

                return authentication_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            authentication_type_1 = HttpIntegrationNoAuth.from_dict(data)

            return authentication_type_1

        authentication = _parse_authentication(d.pop("authentication"))

        organization_id = d.pop("organizationId", UNSET)

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        http_integration = cls(
            name=name,
            url=url,
            method=method,
            authentication=authentication,
            organization_id=organization_id,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
        )

        http_integration.additional_properties = d
        return http_integration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.view_configuration_type import ViewConfigurationType

if TYPE_CHECKING:
    from ..models.bitset_view_configuration import BitsetViewConfiguration
    from ..models.image_view_configuration import ImageViewConfiguration
    from ..models.localization_view_configuration import LocalizationViewConfiguration
    from ..models.location_view_configuration import LocationViewConfiguration
    from ..models.numeric_view_configuration import NumericViewConfiguration
    from ..models.point_cloud_view_configuration import PointCloudViewConfiguration
    from ..models.transform_tree_view_configuration import TransformTreeViewConfiguration


T = TypeVar("T", bound="ViewConfiguration")


@attr.s(auto_attribs=True)
class ViewConfiguration:
    """
    Attributes:
        stream_name (str):
        type (ViewConfigurationType):
        configuration (Union['BitsetViewConfiguration', 'ImageViewConfiguration', 'LocalizationViewConfiguration',
            'LocationViewConfiguration', 'NumericViewConfiguration', 'PointCloudViewConfiguration',
            'TransformTreeViewConfiguration']):
    """

    stream_name: str
    type: ViewConfigurationType
    configuration: Union[
        "BitsetViewConfiguration",
        "ImageViewConfiguration",
        "LocalizationViewConfiguration",
        "LocationViewConfiguration",
        "NumericViewConfiguration",
        "PointCloudViewConfiguration",
        "TransformTreeViewConfiguration",
    ]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.bitset_view_configuration import BitsetViewConfiguration
        from ..models.image_view_configuration import ImageViewConfiguration
        from ..models.localization_view_configuration import LocalizationViewConfiguration
        from ..models.location_view_configuration import LocationViewConfiguration
        from ..models.numeric_view_configuration import NumericViewConfiguration
        from ..models.point_cloud_view_configuration import PointCloudViewConfiguration

        stream_name = self.stream_name
        type = self.type.value

        configuration: Dict[str, Any]

        if isinstance(self.configuration, BitsetViewConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, ImageViewConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, LocationViewConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, NumericViewConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, NumericViewConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, NumericViewConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, LocalizationViewConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, PointCloudViewConfiguration):
            configuration = self.configuration.to_dict()

        else:
            configuration = self.configuration.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "streamName": stream_name,
                "type": type,
                "configuration": configuration,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.bitset_view_configuration import BitsetViewConfiguration
        from ..models.image_view_configuration import ImageViewConfiguration
        from ..models.localization_view_configuration import LocalizationViewConfiguration
        from ..models.location_view_configuration import LocationViewConfiguration
        from ..models.numeric_view_configuration import NumericViewConfiguration
        from ..models.point_cloud_view_configuration import PointCloudViewConfiguration
        from ..models.transform_tree_view_configuration import TransformTreeViewConfiguration

        d = src_dict.copy()
        stream_name = d.pop("streamName")

        type = ViewConfigurationType(d.pop("type"))

        def _parse_configuration(
            data: object,
        ) -> Union[
            "BitsetViewConfiguration",
            "ImageViewConfiguration",
            "LocalizationViewConfiguration",
            "LocationViewConfiguration",
            "NumericViewConfiguration",
            "PointCloudViewConfiguration",
            "TransformTreeViewConfiguration",
        ]:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_0 = BitsetViewConfiguration.from_dict(data)

                return configuration_type_0
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_1 = ImageViewConfiguration.from_dict(data)

                return configuration_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_2 = LocationViewConfiguration.from_dict(data)

                return configuration_type_2
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_3 = NumericViewConfiguration.from_dict(data)

                return configuration_type_3
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_4 = NumericViewConfiguration.from_dict(data)

                return configuration_type_4
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_5 = NumericViewConfiguration.from_dict(data)

                return configuration_type_5
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_6 = LocalizationViewConfiguration.from_dict(data)

                return configuration_type_6
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_7 = PointCloudViewConfiguration.from_dict(data)

                return configuration_type_7
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            configuration_type_8 = TransformTreeViewConfiguration.from_dict(data)

            return configuration_type_8

        configuration = _parse_configuration(d.pop("configuration"))

        view_configuration = cls(
            stream_name=stream_name,
            type=type,
            configuration=configuration,
        )

        view_configuration.additional_properties = d
        return view_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.audio_device import AudioDevice
    from ..models.kernel_info import KernelInfo
    from ..models.network_info import NetworkInfo
    from ..models.node_info import NodeInfo
    from ..models.onvif_device import OnvifDevice
    from ..models.os_info import OsInfo
    from ..models.video_device import VideoDevice


T = TypeVar("T", bound="HwInfo")


@attr.s(auto_attribs=True)
class HwInfo:
    """
    Attributes:
        kernel_info (Union[Unset, KernelInfo]):
        os_info (Union[Unset, OsInfo]):
        node_info (Union[Unset, NodeInfo]):
        network_info (Union[Unset, NetworkInfo]):
        hw_encoding_available (Union[Unset, bool]):
        video_devices (Union[Unset, List['VideoDevice']]):
        audio_capture_devices (Union[Unset, List['AudioDevice']]):
        onvif_devices (Union[Unset, List['OnvifDevice']]):
    """

    kernel_info: Union[Unset, "KernelInfo"] = UNSET
    os_info: Union[Unset, "OsInfo"] = UNSET
    node_info: Union[Unset, "NodeInfo"] = UNSET
    network_info: Union[Unset, "NetworkInfo"] = UNSET
    hw_encoding_available: Union[Unset, bool] = UNSET
    video_devices: Union[Unset, List["VideoDevice"]] = UNSET
    audio_capture_devices: Union[Unset, List["AudioDevice"]] = UNSET
    onvif_devices: Union[Unset, List["OnvifDevice"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        kernel_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.kernel_info, Unset):
            kernel_info = self.kernel_info.to_dict()

        os_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.os_info, Unset):
            os_info = self.os_info.to_dict()

        node_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.node_info, Unset):
            node_info = self.node_info.to_dict()

        network_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.network_info, Unset):
            network_info = self.network_info.to_dict()

        hw_encoding_available = self.hw_encoding_available
        video_devices: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.video_devices, Unset):
            video_devices = []
            for video_devices_item_data in self.video_devices:
                video_devices_item = video_devices_item_data.to_dict()

                video_devices.append(video_devices_item)

        audio_capture_devices: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.audio_capture_devices, Unset):
            audio_capture_devices = []
            for audio_capture_devices_item_data in self.audio_capture_devices:
                audio_capture_devices_item = audio_capture_devices_item_data.to_dict()

                audio_capture_devices.append(audio_capture_devices_item)

        onvif_devices: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.onvif_devices, Unset):
            onvif_devices = []
            for onvif_devices_item_data in self.onvif_devices:
                onvif_devices_item = onvif_devices_item_data.to_dict()

                onvif_devices.append(onvif_devices_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if kernel_info is not UNSET:
            field_dict["kernelInfo"] = kernel_info
        if os_info is not UNSET:
            field_dict["osInfo"] = os_info
        if node_info is not UNSET:
            field_dict["nodeInfo"] = node_info
        if network_info is not UNSET:
            field_dict["networkInfo"] = network_info
        if hw_encoding_available is not UNSET:
            field_dict["hwEncodingAvailable"] = hw_encoding_available
        if video_devices is not UNSET:
            field_dict["videoDevices"] = video_devices
        if audio_capture_devices is not UNSET:
            field_dict["audioCaptureDevices"] = audio_capture_devices
        if onvif_devices is not UNSET:
            field_dict["onvifDevices"] = onvif_devices

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.audio_device import AudioDevice
        from ..models.kernel_info import KernelInfo
        from ..models.network_info import NetworkInfo
        from ..models.node_info import NodeInfo
        from ..models.onvif_device import OnvifDevice
        from ..models.os_info import OsInfo
        from ..models.video_device import VideoDevice

        d = src_dict.copy()
        _kernel_info = d.pop("kernelInfo", UNSET)
        kernel_info: Union[Unset, KernelInfo]
        if isinstance(_kernel_info, Unset):
            kernel_info = UNSET
        else:
            kernel_info = KernelInfo.from_dict(_kernel_info)

        _os_info = d.pop("osInfo", UNSET)
        os_info: Union[Unset, OsInfo]
        if isinstance(_os_info, Unset):
            os_info = UNSET
        else:
            os_info = OsInfo.from_dict(_os_info)

        _node_info = d.pop("nodeInfo", UNSET)
        node_info: Union[Unset, NodeInfo]
        if isinstance(_node_info, Unset):
            node_info = UNSET
        else:
            node_info = NodeInfo.from_dict(_node_info)

        _network_info = d.pop("networkInfo", UNSET)
        network_info: Union[Unset, NetworkInfo]
        if isinstance(_network_info, Unset):
            network_info = UNSET
        else:
            network_info = NetworkInfo.from_dict(_network_info)

        hw_encoding_available = d.pop("hwEncodingAvailable", UNSET)

        video_devices = []
        _video_devices = d.pop("videoDevices", UNSET)
        for video_devices_item_data in _video_devices or []:
            video_devices_item = VideoDevice.from_dict(video_devices_item_data)

            video_devices.append(video_devices_item)

        audio_capture_devices = []
        _audio_capture_devices = d.pop("audioCaptureDevices", UNSET)
        for audio_capture_devices_item_data in _audio_capture_devices or []:
            audio_capture_devices_item = AudioDevice.from_dict(audio_capture_devices_item_data)

            audio_capture_devices.append(audio_capture_devices_item)

        onvif_devices = []
        _onvif_devices = d.pop("onvifDevices", UNSET)
        for onvif_devices_item_data in _onvif_devices or []:
            onvif_devices_item = OnvifDevice.from_dict(onvif_devices_item_data)

            onvif_devices.append(onvif_devices_item)

        hw_info = cls(
            kernel_info=kernel_info,
            os_info=os_info,
            node_info=node_info,
            network_info=network_info,
            hw_encoding_available=hw_encoding_available,
            video_devices=video_devices,
            audio_capture_devices=audio_capture_devices,
            onvif_devices=onvif_devices,
        )

        hw_info.additional_properties = d
        return hw_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from formant.sdk.cloud.v2.src.auth import Auth
from formant.sdk.cloud.v2.src.resources.queries.queries import Queries
from formant.sdk.cloud.v2.src.resources.count.count import Count
from formant.sdk.cloud.v2.src.resources.stream_current.stream_current import (
    StreamCurrent,
)
from formant.sdk.cloud.v2.src.resources.metadata.metadata import Metadata
from formant.sdk.cloud.v2.src.resources.online_devices.online_devices import (
    OnlineDevices,
)
from formant.sdk.cloud.v2.src.resources.presence.presence import Presence


class QueryAPI(Auth):
    def __init__(self, email: str, password: str, base_url: str, timeout: int = 30):
        super().__init__(
            email=email,
            password=password,
            api="queries",
            base_url=base_url,
            timeout=timeout,
        )

        self.queries = Queries(self.get_client)
        self.count = Count(self.get_client)
        self.stream_current = StreamCurrent(self.get_client)
        self.metadata = Metadata(self.get_client)
        self.online_devices = OnlineDevices(self.get_client)
        self.presence = Presence(self.get_client)



from enum import Enum


class InterventionResponseInterventionType(str, Enum):
    SELECTION = "selection"
    LABELING = "labeling"
    TELEOP = "teleop"
    PHYSICAL = "physical"

    def __str__(self) -> str:
        return str(self.value)



from typing import Callable, Union, Any
from formant.sdk.cloud.v2.formant_admin_api_client import Client, AuthenticatedClient

class Resources:

    def __init__(self, get_client: Callable[[None], Union[Any, Client, AuthenticatedClient]]):
        self._get_client = get_client


import unittest
from formant.sdk.cloud.v2.src.admin_api import AdminAPI
from formant.sdk.cloud.v2.src.resources.adapters import *
import os
import json

EMAIL = os.getenv("FORMANT_EMAIL")
PASSWORD = os.getenv("FORMANT_PASSWORD")
BASE_URL = "https://api.formant.io/v1"


class TestAdapters(unittest.TestCase):
    def __init__(self, *args, **kwargs):
        super(TestAdapters, self).__init__(*args, **kwargs)
        self.client = AdminAPI(email=EMAIL, password=PASSWORD, base_url=BASE_URL)

    # def test_create_adapter(self):
    #     name = "generic-test"
    #     file_id = "cd860575-df44-40ea-a1ef-c5860c1a8992"
    #     exec_command = "test"
    #     adapter = Adapter(name, file_id, exec_command)
    #     result = self.client.adapters.create(adapter)
    #     self.assertEqual(result.status_code, 201)
    #     content = json.loads(result.content)
    #     id = content["id"]
    #     result = self.client.adapters.delete(id)
    #     self.assertEqual(result.status_code, 204)


unittest.main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/math.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/math.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aprotos/model/v1/math.proto\x12\x08v1.model\"\x18\n\x07Numeric\x12\r\n\x05value\x18\x01 \x01(\x01\"=\n\x0fNumericSetEntry\x12\r\n\x05value\x18\x01 \x01(\x01\x12\r\n\x05label\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\"9\n\nNumericSet\x12+\n\x08numerics\x18\x01 \x03(\x0b\x32\x19.v1.model.NumericSetEntry\"!\n\x03\x42it\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"%\n\x06\x42itset\x12\x1b\n\x04\x62its\x18\x01 \x03(\x0b\x32\r.v1.model.Bit\"N\n\x05Twist\x12!\n\x06linear\x18\x01 \x01(\x0b\x32\x11.v1.model.Vector3\x12\"\n\x07\x61ngular\x18\x02 \x01(\x0b\x32\x11.v1.model.Vector3\"[\n\tTransform\x12&\n\x0btranslation\x18\x01 \x01(\x0b\x32\x11.v1.model.Vector3\x12&\n\x08rotation\x18\x02 \x01(\x0b\x32\x14.v1.model.Quaternion\"c\n\x0eTransformFrame\x12\x14\n\x0cparent_frame\x18\x01 \x01(\t\x12\x13\n\x0b\x63hild_frame\x18\x02 \x01(\t\x12&\n\ttransform\x18\x03 \x01(\x0b\x32\x13.v1.model.Transform\"*\n\x07Vector3\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"(\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"8\n\nQuaternion\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\t\n\x01w\x18\x04 \x01(\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.math_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_NUMERIC']._serialized_start=40
  _globals['_NUMERIC']._serialized_end=64
  _globals['_NUMERICSETENTRY']._serialized_start=66
  _globals['_NUMERICSETENTRY']._serialized_end=127
  _globals['_NUMERICSET']._serialized_start=129
  _globals['_NUMERICSET']._serialized_end=186
  _globals['_BIT']._serialized_start=188
  _globals['_BIT']._serialized_end=221
  _globals['_BITSET']._serialized_start=223
  _globals['_BITSET']._serialized_end=260
  _globals['_TWIST']._serialized_start=262
  _globals['_TWIST']._serialized_end=340
  _globals['_TRANSFORM']._serialized_start=342
  _globals['_TRANSFORM']._serialized_end=433
  _globals['_TRANSFORMFRAME']._serialized_start=435
  _globals['_TRANSFORMFRAME']._serialized_end=534
  _globals['_VECTOR3']._serialized_start=536
  _globals['_VECTOR3']._serialized_end=578
  _globals['_POINT']._serialized_start=580
  _globals['_POINT']._serialized_end=620
  _globals['_QUATERNION']._serialized_start=622
  _globals['_QUATERNION']._serialized_end=678
# @@protoc_insertion_point(module_scope)



from enum import Enum


class TeleopJoystickAxisConfigurationDimension(str, Enum):
    LINEAR_X = "linear-x"
    LINEAR_Y = "linear-y"
    LINEAR_Z = "linear-z"
    ANGULAR_X = "angular-x"
    ANGULAR_Y = "angular-y"
    ANGULAR_Z = "angular-z"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.capture_session import CaptureSession
    from ..models.user_scope import UserScope


T = TypeVar("T", bound="AuthenticateCaptureCodeResponse")


@attr.s(auto_attribs=True)
class AuthenticateCaptureCodeResponse:
    """
    Attributes:
        token (str):
        capture_session (Union[Unset, List['CaptureSession']]):
        scope (Union[Unset, List[Optional['UserScope']]]):
    """

    token: str
    capture_session: Union[Unset, List["CaptureSession"]] = UNSET
    scope: Union[Unset, List[Optional["UserScope"]]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        token = self.token
        capture_session: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.capture_session, Unset):
            capture_session = []
            for capture_session_item_data in self.capture_session:
                capture_session_item = capture_session_item_data.to_dict()

                capture_session.append(capture_session_item)

        scope: Union[Unset, List[Optional[Dict[str, Any]]]] = UNSET
        if not isinstance(self.scope, Unset):
            scope = []
            for scope_item_data in self.scope:
                scope_item = scope_item_data.to_dict() if scope_item_data else None

                scope.append(scope_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "token": token,
            }
        )
        if capture_session is not UNSET:
            field_dict["captureSession"] = capture_session
        if scope is not UNSET:
            field_dict["scope"] = scope

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.capture_session import CaptureSession
        from ..models.user_scope import UserScope

        d = src_dict.copy()
        token = d.pop("token")

        capture_session = []
        _capture_session = d.pop("captureSession", UNSET)
        for capture_session_item_data in _capture_session or []:
            capture_session_item = CaptureSession.from_dict(capture_session_item_data)

            capture_session.append(capture_session_item)

        scope = []
        _scope = d.pop("scope", UNSET)
        for scope_item_data in _scope or []:
            _scope_item = scope_item_data
            scope_item: Optional[UserScope]
            if _scope_item is None:
                scope_item = None
            else:
                scope_item = UserScope.from_dict(_scope_item)

            scope.append(scope_item)

        authenticate_capture_code_response = cls(
            token=token,
            capture_session=capture_session,
            scope=scope,
        )

        authenticate_capture_code_response.additional_properties = d
        return authenticate_capture_code_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.sso_configuration_authentication_flow import SsoConfigurationAuthenticationFlow
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.sso_group_name_to_team_mapping import SsoGroupNameToTeamMapping


T = TypeVar("T", bound="SsoConfiguration")


@attr.s(auto_attribs=True)
class SsoConfiguration:
    """
    Attributes:
        domain (str):
        authentication_flow (SsoConfigurationAuthenticationFlow):
        enabled (bool):
        organization_id (Union[Unset, str]): ID of the organization to which to apply this SSO configuration.
        default_role_id (Union[Unset, str]): Default role assigned to all new users who sign up via SSO. Either a
            default team or a default role is required.
        default_team_id (Union[Unset, str]): Default team to which all new users who sign up via SSO will be assigned.
            Either a default team or a default role is required.
        default_account_id (Union[Unset, None, str]):
        client_id (Union[Unset, None, str]):
        issuer (Union[Unset, None, str]):
        sso_group_name_to_team_mappings (Union[Unset, List['SsoGroupNameToTeamMapping']]):
        allow_password_login (Union[Unset, bool]):
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
    """

    domain: str
    authentication_flow: SsoConfigurationAuthenticationFlow
    enabled: bool
    organization_id: Union[Unset, str] = UNSET
    default_role_id: Union[Unset, str] = UNSET
    default_team_id: Union[Unset, str] = UNSET
    default_account_id: Union[Unset, None, str] = UNSET
    client_id: Union[Unset, None, str] = UNSET
    issuer: Union[Unset, None, str] = UNSET
    sso_group_name_to_team_mappings: Union[Unset, List["SsoGroupNameToTeamMapping"]] = UNSET
    allow_password_login: Union[Unset, bool] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        domain = self.domain
        authentication_flow = self.authentication_flow.value

        enabled = self.enabled
        organization_id = self.organization_id
        default_role_id = self.default_role_id
        default_team_id = self.default_team_id
        default_account_id = self.default_account_id
        client_id = self.client_id
        issuer = self.issuer
        sso_group_name_to_team_mappings: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.sso_group_name_to_team_mappings, Unset):
            sso_group_name_to_team_mappings = []
            for sso_group_name_to_team_mappings_item_data in self.sso_group_name_to_team_mappings:
                sso_group_name_to_team_mappings_item = sso_group_name_to_team_mappings_item_data.to_dict()

                sso_group_name_to_team_mappings.append(sso_group_name_to_team_mappings_item)

        allow_password_login = self.allow_password_login
        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "domain": domain,
                "authenticationFlow": authentication_flow,
                "enabled": enabled,
            }
        )
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if default_role_id is not UNSET:
            field_dict["defaultRoleId"] = default_role_id
        if default_team_id is not UNSET:
            field_dict["defaultTeamId"] = default_team_id
        if default_account_id is not UNSET:
            field_dict["defaultAccountId"] = default_account_id
        if client_id is not UNSET:
            field_dict["clientId"] = client_id
        if issuer is not UNSET:
            field_dict["issuer"] = issuer
        if sso_group_name_to_team_mappings is not UNSET:
            field_dict["ssoGroupNameToTeamMappings"] = sso_group_name_to_team_mappings
        if allow_password_login is not UNSET:
            field_dict["allowPasswordLogin"] = allow_password_login
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.sso_group_name_to_team_mapping import SsoGroupNameToTeamMapping

        d = src_dict.copy()
        domain = d.pop("domain")

        authentication_flow = SsoConfigurationAuthenticationFlow(d.pop("authenticationFlow"))

        enabled = d.pop("enabled")

        organization_id = d.pop("organizationId", UNSET)

        default_role_id = d.pop("defaultRoleId", UNSET)

        default_team_id = d.pop("defaultTeamId", UNSET)

        default_account_id = d.pop("defaultAccountId", UNSET)

        client_id = d.pop("clientId", UNSET)

        issuer = d.pop("issuer", UNSET)

        sso_group_name_to_team_mappings = []
        _sso_group_name_to_team_mappings = d.pop("ssoGroupNameToTeamMappings", UNSET)
        for sso_group_name_to_team_mappings_item_data in _sso_group_name_to_team_mappings or []:
            sso_group_name_to_team_mappings_item = SsoGroupNameToTeamMapping.from_dict(
                sso_group_name_to_team_mappings_item_data
            )

            sso_group_name_to_team_mappings.append(sso_group_name_to_team_mappings_item)

        allow_password_login = d.pop("allowPasswordLogin", UNSET)

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        sso_configuration = cls(
            domain=domain,
            authentication_flow=authentication_flow,
            enabled=enabled,
            organization_id=organization_id,
            default_role_id=default_role_id,
            default_team_id=default_team_id,
            default_account_id=default_account_id,
            client_id=client_id,
            issuer=issuer,
            sso_group_name_to_team_mappings=sso_group_name_to_team_mappings,
            allow_password_login=allow_password_login,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
        )

        sso_configuration.additional_properties = d
        return sso_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/event.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bprotos/model/v1/event.proto\x12\x08v1.model\"\xc0\x02\n\x05\x45vent\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x15\n\rend_timestamp\x18\x08 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x13\n\x0bstream_type\x18\x04 \x01(\t\x12\x1c\n\x14notification_enabled\x18\x05 \x01(\x08\x12$\n\x08severity\x18\t \x01(\x0e\x32\x12.v1.model.Severity\x12\n\n\x02id\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x18\n\x10\x65vent_trigger_id\x18\x0c \x01(\t\x12\'\n\x04tags\x18\x06 \x03(\x0b\x32\x19.v1.model.Event.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"\xa2\x01\n\x17\x41gentEventConfiguration\x12\x33\n\x0e\x65vent_triggers\x18\x01 \x03(\x0b\x32\x1b.v1.model.AgentEventTrigger\x12<\n\x17stateful_event_triggers\x18\x03 \x03(\x0b\x32\x1b.v1.model.AgentEventTrigger\x12\x14\n\x0clast_updated\x18\x02 \x01(\x03\"\xd6\x02\n\x11\x41gentEventTrigger\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06stream\x18\x02 \x01(\t\x12\x10\n\x08interval\x18\x03 \x01(\x03\x12&\n\tcondition\x18\x04 \x01(\x0b\x32\x13.v1.model.Condition\x12*\n\rexitCondition\x18\x05 \x01(\x0b\x32\x13.v1.model.Condition\x12\x19\n\x11isStatefulTrigger\x18\x06 \x01(\x08\x12L\n\x1cstatefulTriggerConfiguration\x18\x07 \x01(\x0b\x32&.v1.model.StatefulTriggerConfiguration\x12\x0f\n\x07message\x18\x08 \x01(\t\x12\x15\n\rmessageFormat\x18\x0b \x01(\t\x12\x10\n\x08severity\x18\t \x01(\t\x12\x1c\n\x14notification_enabled\x18\n \x01(\x08\"\x85\x04\n\tCondition\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12;\n\x08presence\x18\x02 \x01(\x0b\x32\'.v1.model.PresenceEventTriggerConditionH\x00\x12=\n\tthreshold\x18\x03 \x01(\x0b\x32(.v1.model.ThresholdEventTriggerConditionH\x00\x12\x35\n\x05regex\x18\x04 \x01(\x0b\x32$.v1.model.RegexEventTriggerConditionH\x00\x12\x37\n\x06\x62itset\x18\x05 \x01(\x0b\x32%.v1.model.BitsetEventTriggerConditionH\x00\x12\x39\n\x07\x62\x61ttery\x18\x06 \x01(\x0b\x32&.v1.model.BatteryEventTriggerConditionH\x00\x12<\n\x07numeric\x18\x07 \x01(\x0b\x32).v1.model.NumericSetEventTriggerConditionH\x00\x12\x33\n\x04json\x18\x08 \x01(\x0b\x32#.v1.model.JsonEventTriggerConditionH\x00\x12\x41\n\x0b\x61utoresolve\x18\t \x01(\x0b\x32*.v1.model.AutoresolveEventTriggerConditionH\x00\x42\x0b\n\tcondition\"\x1f\n\x1dPresenceEventTriggerCondition\"\"\n AutoresolveEventTriggerCondition\"^\n\x1eThresholdEventTriggerCondition\x12\r\n\x05value\x18\x01 \x01(\x01\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ThresholdOperator\"^\n\x10NumericCondition\x12\r\n\x05label\x18\x01 \x01(\t\x12;\n\tcondition\x18\x02 \x01(\x0b\x32(.v1.model.ThresholdEventTriggerCondition\"\x80\x01\n\x1fNumericSetEventTriggerCondition\x12.\n\nconditions\x18\x01 \x03(\x0b\x32\x1a.v1.model.NumericCondition\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\"\xa5\x01\n\x10\x42\x61tteryCondition\x12%\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x16.v1.model.BatteryField\x12;\n\tcondition\x18\x02 \x01(\x0b\x32(.v1.model.ThresholdEventTriggerCondition\x12-\n\x08operator\x18\x03 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\"}\n\x1c\x42\x61tteryEventTriggerCondition\x12.\n\nconditions\x18\x01 \x03(\x0b\x32\x1a.v1.model.BatteryCondition\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\"+\n\x1aRegexEventTriggerCondition\x12\r\n\x05value\x18\x01 \x01(\t\"\x7f\n\x1b\x42itsetEventTriggerCondition\x12\x31\n\x0e\x62it_conditions\x18\x01 \x03(\x0b\x32\x19.v1.model.BitsetCondition\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\";\n\x0f\x42itsetCondition\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04true\x18\x02 \x01(\x08\x12\r\n\x05\x66\x61lse\x18\x03 \x01(\x08\",\n\x19JsonEventTriggerCondition\x12\x0f\n\x07jqQuery\x18\x01 \x01(\t\"W\n\x1cStatefulTriggerConfiguration\x12\x1b\n\x13\x65mitOnEnteringState\x18\x01 \x01(\x08\x12\x1a\n\x12\x65mitOnLeavingState\x18\x02 \x01(\x08*:\n\x08Severity\x12\x08\n\x04INFO\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0c\n\x08\x43RITICAL\x10\x03*D\n\x0c\x42\x61tteryField\x12\n\n\x06\x43harge\x10\x00\x12\x0b\n\x07\x43urrent\x10\x01\x12\x0e\n\nPercentage\x10\x02\x12\x0b\n\x07Voltage\x10\x03*F\n\x11ThresholdOperator\x12\x06\n\x02LT\x10\x00\x12\x07\n\x03LTE\x10\x01\x12\x06\n\x02GT\x10\x02\x12\x07\n\x03GTE\x10\x03\x12\x06\n\x02\x45Q\x10\x04\x12\x07\n\x03NEQ\x10\x05*%\n\x11\x43onditionOperator\x12\x07\n\x03\x41NY\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_EVENT_TAGSENTRY']._loaded_options = None
  _globals['_EVENT_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_SEVERITY']._serialized_start=2451
  _globals['_SEVERITY']._serialized_end=2509
  _globals['_BATTERYFIELD']._serialized_start=2511
  _globals['_BATTERYFIELD']._serialized_end=2579
  _globals['_THRESHOLDOPERATOR']._serialized_start=2581
  _globals['_THRESHOLDOPERATOR']._serialized_end=2651
  _globals['_CONDITIONOPERATOR']._serialized_start=2653
  _globals['_CONDITIONOPERATOR']._serialized_end=2690
  _globals['_EVENT']._serialized_start=42
  _globals['_EVENT']._serialized_end=362
  _globals['_EVENT_TAGSENTRY']._serialized_start=313
  _globals['_EVENT_TAGSENTRY']._serialized_end=356
  _globals['_AGENTEVENTCONFIGURATION']._serialized_start=365
  _globals['_AGENTEVENTCONFIGURATION']._serialized_end=527
  _globals['_AGENTEVENTTRIGGER']._serialized_start=530
  _globals['_AGENTEVENTTRIGGER']._serialized_end=872
  _globals['_CONDITION']._serialized_start=875
  _globals['_CONDITION']._serialized_end=1392
  _globals['_PRESENCEEVENTTRIGGERCONDITION']._serialized_start=1394
  _globals['_PRESENCEEVENTTRIGGERCONDITION']._serialized_end=1425
  _globals['_AUTORESOLVEEVENTTRIGGERCONDITION']._serialized_start=1427
  _globals['_AUTORESOLVEEVENTTRIGGERCONDITION']._serialized_end=1461
  _globals['_THRESHOLDEVENTTRIGGERCONDITION']._serialized_start=1463
  _globals['_THRESHOLDEVENTTRIGGERCONDITION']._serialized_end=1557
  _globals['_NUMERICCONDITION']._serialized_start=1559
  _globals['_NUMERICCONDITION']._serialized_end=1653
  _globals['_NUMERICSETEVENTTRIGGERCONDITION']._serialized_start=1656
  _globals['_NUMERICSETEVENTTRIGGERCONDITION']._serialized_end=1784
  _globals['_BATTERYCONDITION']._serialized_start=1787
  _globals['_BATTERYCONDITION']._serialized_end=1952
  _globals['_BATTERYEVENTTRIGGERCONDITION']._serialized_start=1954
  _globals['_BATTERYEVENTTRIGGERCONDITION']._serialized_end=2079
  _globals['_REGEXEVENTTRIGGERCONDITION']._serialized_start=2081
  _globals['_REGEXEVENTTRIGGERCONDITION']._serialized_end=2124
  _globals['_BITSETEVENTTRIGGERCONDITION']._serialized_start=2126
  _globals['_BITSETEVENTTRIGGERCONDITION']._serialized_end=2253
  _globals['_BITSETCONDITION']._serialized_start=2255
  _globals['_BITSETCONDITION']._serialized_end=2314
  _globals['_JSONEVENTTRIGGERCONDITION']._serialized_start=2316
  _globals['_JSONEVENTTRIGGERCONDITION']._serialized_end=2360
  _globals['_STATEFULTRIGGERCONFIGURATION']._serialized_start=2362
  _globals['_STATEFULTRIGGERCONFIGURATION']._serialized_end=2449
# @@protoc_insertion_point(module_scope)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.device_stream_configuration_quality import DeviceStreamConfigurationQuality
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.device_stream_configuration_tags import DeviceStreamConfigurationTags
    from ..models.device_stream_custom_configuration import DeviceStreamCustomConfiguration
    from ..models.device_stream_directory_watch_configuration import DeviceStreamDirectoryWatchConfiguration
    from ..models.device_stream_file_tail_configuration import DeviceStreamFileTailConfiguration
    from ..models.device_stream_hardware_configuration import DeviceStreamHardwareConfiguration
    from ..models.device_stream_ros_localization_configuration import DeviceStreamRosLocalizationConfiguration
    from ..models.device_stream_ros_topic_configuration import DeviceStreamRosTopicConfiguration
    from ..models.device_stream_ros_transform_tree_configuration import DeviceStreamRosTransformTreeConfiguration
    from ..models.device_stream_transform_configuration import DeviceStreamTransformConfiguration
    from ..models.validation_configuration import ValidationConfiguration


T = TypeVar("T", bound="DeviceStreamConfiguration")


@attr.s(auto_attribs=True)
class DeviceStreamConfiguration:
    """
    Attributes:
        name (str):
        configuration (Union['DeviceStreamCustomConfiguration', 'DeviceStreamDirectoryWatchConfiguration',
            'DeviceStreamFileTailConfiguration', 'DeviceStreamHardwareConfiguration',
            'DeviceStreamRosLocalizationConfiguration', 'DeviceStreamRosTopicConfiguration',
            'DeviceStreamRosTransformTreeConfiguration']):
        tags (Union[Unset, DeviceStreamConfigurationTags]):
        throttle_hz (Union[Unset, None, float]):
        disabled (Union[Unset, None, bool]):
        on_demand (Union[Unset, None, bool]):
        validation (Union[Unset, None, ValidationConfiguration]):
        transform (Union[Unset, None, DeviceStreamTransformConfiguration]):
        quality (Union[Unset, DeviceStreamConfigurationQuality]):
    """

    name: str
    configuration: Union[
        "DeviceStreamCustomConfiguration",
        "DeviceStreamDirectoryWatchConfiguration",
        "DeviceStreamFileTailConfiguration",
        "DeviceStreamHardwareConfiguration",
        "DeviceStreamRosLocalizationConfiguration",
        "DeviceStreamRosTopicConfiguration",
        "DeviceStreamRosTransformTreeConfiguration",
    ]
    tags: Union[Unset, "DeviceStreamConfigurationTags"] = UNSET
    throttle_hz: Union[Unset, None, float] = UNSET
    disabled: Union[Unset, None, bool] = UNSET
    on_demand: Union[Unset, None, bool] = UNSET
    validation: Union[Unset, None, "ValidationConfiguration"] = UNSET
    transform: Union[Unset, None, "DeviceStreamTransformConfiguration"] = UNSET
    quality: Union[Unset, DeviceStreamConfigurationQuality] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.device_stream_custom_configuration import DeviceStreamCustomConfiguration
        from ..models.device_stream_directory_watch_configuration import DeviceStreamDirectoryWatchConfiguration
        from ..models.device_stream_hardware_configuration import DeviceStreamHardwareConfiguration
        from ..models.device_stream_ros_localization_configuration import DeviceStreamRosLocalizationConfiguration
        from ..models.device_stream_ros_topic_configuration import DeviceStreamRosTopicConfiguration
        from ..models.device_stream_ros_transform_tree_configuration import DeviceStreamRosTransformTreeConfiguration

        name = self.name
        configuration: Dict[str, Any]

        if isinstance(self.configuration, DeviceStreamHardwareConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, DeviceStreamCustomConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, DeviceStreamRosTopicConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, DeviceStreamRosLocalizationConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, DeviceStreamRosTransformTreeConfiguration):
            configuration = self.configuration.to_dict()

        elif isinstance(self.configuration, DeviceStreamDirectoryWatchConfiguration):
            configuration = self.configuration.to_dict()

        else:
            configuration = self.configuration.to_dict()

        tags: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict()

        throttle_hz = self.throttle_hz
        disabled = self.disabled
        on_demand = self.on_demand
        validation: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.validation, Unset):
            validation = self.validation.to_dict() if self.validation else None

        transform: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.transform, Unset):
            transform = self.transform.to_dict() if self.transform else None

        quality: Union[Unset, str] = UNSET
        if not isinstance(self.quality, Unset):
            quality = self.quality.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "configuration": configuration,
            }
        )
        if tags is not UNSET:
            field_dict["tags"] = tags
        if throttle_hz is not UNSET:
            field_dict["throttleHz"] = throttle_hz
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if on_demand is not UNSET:
            field_dict["onDemand"] = on_demand
        if validation is not UNSET:
            field_dict["validation"] = validation
        if transform is not UNSET:
            field_dict["transform"] = transform
        if quality is not UNSET:
            field_dict["quality"] = quality

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.device_stream_configuration_tags import DeviceStreamConfigurationTags
        from ..models.device_stream_custom_configuration import DeviceStreamCustomConfiguration
        from ..models.device_stream_directory_watch_configuration import DeviceStreamDirectoryWatchConfiguration
        from ..models.device_stream_file_tail_configuration import DeviceStreamFileTailConfiguration
        from ..models.device_stream_hardware_configuration import DeviceStreamHardwareConfiguration
        from ..models.device_stream_ros_localization_configuration import DeviceStreamRosLocalizationConfiguration
        from ..models.device_stream_ros_topic_configuration import DeviceStreamRosTopicConfiguration
        from ..models.device_stream_ros_transform_tree_configuration import DeviceStreamRosTransformTreeConfiguration
        from ..models.device_stream_transform_configuration import DeviceStreamTransformConfiguration
        from ..models.validation_configuration import ValidationConfiguration

        d = src_dict.copy()
        name = d.pop("name")

        def _parse_configuration(
            data: object,
        ) -> Union[
            "DeviceStreamCustomConfiguration",
            "DeviceStreamDirectoryWatchConfiguration",
            "DeviceStreamFileTailConfiguration",
            "DeviceStreamHardwareConfiguration",
            "DeviceStreamRosLocalizationConfiguration",
            "DeviceStreamRosTopicConfiguration",
            "DeviceStreamRosTransformTreeConfiguration",
        ]:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_0 = DeviceStreamHardwareConfiguration.from_dict(data)

                return configuration_type_0
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_1 = DeviceStreamCustomConfiguration.from_dict(data)

                return configuration_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_2 = DeviceStreamRosTopicConfiguration.from_dict(data)

                return configuration_type_2
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_3 = DeviceStreamRosLocalizationConfiguration.from_dict(data)

                return configuration_type_3
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_4 = DeviceStreamRosTransformTreeConfiguration.from_dict(data)

                return configuration_type_4
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                configuration_type_5 = DeviceStreamDirectoryWatchConfiguration.from_dict(data)

                return configuration_type_5
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            configuration_type_6 = DeviceStreamFileTailConfiguration.from_dict(data)

            return configuration_type_6

        configuration = _parse_configuration(d.pop("configuration"))

        _tags = d.pop("tags", UNSET)
        tags: Union[Unset, DeviceStreamConfigurationTags]
        if isinstance(_tags, Unset):
            tags = UNSET
        else:
            tags = DeviceStreamConfigurationTags.from_dict(_tags)

        throttle_hz = d.pop("throttleHz", UNSET)

        disabled = d.pop("disabled", UNSET)

        on_demand = d.pop("onDemand", UNSET)

        _validation = d.pop("validation", UNSET)
        validation: Union[Unset, None, ValidationConfiguration]
        if _validation is None:
            validation = None
        elif isinstance(_validation, Unset):
            validation = UNSET
        else:
            validation = ValidationConfiguration.from_dict(_validation)

        _transform = d.pop("transform", UNSET)
        transform: Union[Unset, None, DeviceStreamTransformConfiguration]
        if _transform is None:
            transform = None
        elif isinstance(_transform, Unset):
            transform = UNSET
        else:
            transform = DeviceStreamTransformConfiguration.from_dict(_transform)

        _quality = d.pop("quality", UNSET)
        quality: Union[Unset, DeviceStreamConfigurationQuality]
        if isinstance(_quality, Unset):
            quality = UNSET
        else:
            quality = DeviceStreamConfigurationQuality(_quality)

        device_stream_configuration = cls(
            name=name,
            configuration=configuration,
            tags=tags,
            throttle_hz=throttle_hz,
            disabled=disabled,
            on_demand=on_demand,
            validation=validation,
            transform=transform,
            quality=quality,
        )

        device_stream_configuration.additional_properties = d
        return device_stream_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.scope_filter_types_item import ScopeFilterTypesItem
from ..types import UNSET, Unset

T = TypeVar("T", bound="ScopeFilter")


@attr.s(auto_attribs=True)
class ScopeFilter:
    """
    Attributes:
        start (Union[Unset, datetime.datetime]):
        end (Union[Unset, datetime.datetime]):
        tags (Union[Unset, Any]):
        device_ids (Union[Unset, List[str]]):
        names (Union[Unset, List[str]]):
        types (Union[Unset, List[ScopeFilterTypesItem]]):
        not_tags (Union[Unset, Any]):
        not_names (Union[Unset, List[str]]):
        agent_ids (Union[Unset, List[str]]):
    """

    start: Union[Unset, datetime.datetime] = UNSET
    end: Union[Unset, datetime.datetime] = UNSET
    tags: Union[Unset, Any] = UNSET
    device_ids: Union[Unset, List[str]] = UNSET
    names: Union[Unset, List[str]] = UNSET
    types: Union[Unset, List[ScopeFilterTypesItem]] = UNSET
    not_tags: Union[Unset, Any] = UNSET
    not_names: Union[Unset, List[str]] = UNSET
    agent_ids: Union[Unset, List[str]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        start: Union[Unset, str] = UNSET
        if not isinstance(self.start, Unset):
            start = self.start.isoformat()

        end: Union[Unset, str] = UNSET
        if not isinstance(self.end, Unset):
            end = self.end.isoformat()

        tags = self.tags
        device_ids: Union[Unset, List[str]] = UNSET
        if not isinstance(self.device_ids, Unset):
            device_ids = self.device_ids

        names: Union[Unset, List[str]] = UNSET
        if not isinstance(self.names, Unset):
            names = self.names

        types: Union[Unset, List[str]] = UNSET
        if not isinstance(self.types, Unset):
            types = []
            for types_item_data in self.types:
                types_item = types_item_data.value

                types.append(types_item)

        not_tags = self.not_tags
        not_names: Union[Unset, List[str]] = UNSET
        if not isinstance(self.not_names, Unset):
            not_names = self.not_names

        agent_ids: Union[Unset, List[str]] = UNSET
        if not isinstance(self.agent_ids, Unset):
            agent_ids = self.agent_ids

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if start is not UNSET:
            field_dict["start"] = start
        if end is not UNSET:
            field_dict["end"] = end
        if tags is not UNSET:
            field_dict["tags"] = tags
        if device_ids is not UNSET:
            field_dict["deviceIds"] = device_ids
        if names is not UNSET:
            field_dict["names"] = names
        if types is not UNSET:
            field_dict["types"] = types
        if not_tags is not UNSET:
            field_dict["notTags"] = not_tags
        if not_names is not UNSET:
            field_dict["notNames"] = not_names
        if agent_ids is not UNSET:
            field_dict["agentIds"] = agent_ids

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _start = d.pop("start", UNSET)
        start: Union[Unset, datetime.datetime]
        if isinstance(_start, Unset):
            start = UNSET
        else:
            start = isoparse(_start)

        _end = d.pop("end", UNSET)
        end: Union[Unset, datetime.datetime]
        if isinstance(_end, Unset):
            end = UNSET
        else:
            end = isoparse(_end)

        tags = d.pop("tags", UNSET)

        device_ids = cast(List[str], d.pop("deviceIds", UNSET))

        names = cast(List[str], d.pop("names", UNSET))

        types = []
        _types = d.pop("types", UNSET)
        for types_item_data in _types or []:
            types_item = ScopeFilterTypesItem(types_item_data)

            types.append(types_item)

        not_tags = d.pop("notTags", UNSET)

        not_names = cast(List[str], d.pop("notNames", UNSET))

        agent_ids = cast(List[str], d.pop("agentIds", UNSET))

        scope_filter = cls(
            start=start,
            end=end,
            tags=tags,
            device_ids=device_ids,
            names=names,
            types=types,
            not_tags=not_tags,
            not_names=not_names,
            agent_ids=agent_ids,
        )

        scope_filter.additional_properties = d
        return scope_filter

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from formant.sdk.cloud.v2.formant_admin_api_client.models import AnnotationStreamType, AnnotationFieldValueTags, FocusedDatapoint, AnnotationTemplate, AnnotationTags, AnnotationField, AnnotationFieldType, SheetParameters, AnnotationType, AnnotationTemplateListResponse, ScopeFilter, AnnotationMetadata, TagParameters, AnnotationTemplateTags, AnnotationFieldValuesRequest, UserParameters, Annotation, UserParametersRolesItem, ScopeFilterTypesItem, AnnotationFieldValuesRequestTags, AnnotationFieldValue, AnnotationFieldValuesResponse
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation import annotation_controller_post
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation_template import annotation_template_controller_list, annotation_template_controller_get_one
from formant.sdk.cloud.v2.formant_admin_api_client.types import *


from formant.sdk.cloud.v2.src.auth import Auth
from formant.sdk.cloud.v2.src.resources.ingest.ingest import Ingest


class IngestAPI(Auth):
    def __init__(self, email: str, password: str, base_url: str, timeout: int = 30):
        super().__init__(
            email=email,
            password=password,
            api="ingest",
            base_url=base_url,
            timeout=timeout,
        )

        self.ingest = Ingest(self.get_client)



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.usage_record_type import UsageRecordType
from ..types import UNSET, Unset

T = TypeVar("T", bound="UsageRecord")


@attr.s(auto_attribs=True)
class UsageRecord:
    """
    Attributes:
        organization_id (str):
        type (UsageRecordType):
        time (datetime.datetime):
        value (int):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
    """

    organization_id: str
    type: UsageRecordType
    time: datetime.datetime
    value: int
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        organization_id = self.organization_id
        type = self.type.value

        time = self.time.isoformat()

        value = self.value
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "organizationId": organization_id,
                "type": type,
                "time": time,
                "value": value,
            }
        )
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        organization_id = d.pop("organizationId")

        type = UsageRecordType(d.pop("type"))

        time = isoparse(d.pop("time"))

        value = d.pop("value")

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        usage_record = cls(
            organization_id=organization_id,
            type=type,
            time=time,
            value=value,
            created_at=created_at,
            updated_at=updated_at,
        )

        usage_record.additional_properties = d
        return usage_record

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/datapoint.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/datapoint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import file_pb2 as protos_dot_model_dot_v1_dot_file__pb2
from formant.protos.model.v1 import health_pb2 as protos_dot_model_dot_v1_dot_health__pb2
from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2
from formant.protos.model.v1 import navigation_pb2 as protos_dot_model_dot_v1_dot_navigation__pb2
from formant.protos.model.v1 import text_pb2 as protos_dot_model_dot_v1_dot_text__pb2
from formant.protos.model.v1 import media_pb2 as protos_dot_model_dot_v1_dot_media__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fprotos/model/v1/datapoint.proto\x12\x08v1.model\x1a\x1aprotos/model/v1/file.proto\x1a\x1cprotos/model/v1/health.proto\x1a\x1aprotos/model/v1/math.proto\x1a protos/model/v1/navigation.proto\x1a\x1aprotos/model/v1/text.proto\x1a\x1bprotos/model/v1/media.proto\"\xea\x05\n\tDatapoint\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12+\n\x04tags\x18\x03 \x03(\x0b\x32\x1d.v1.model.Datapoint.TagsEntry\x12\x1e\n\x04text\x18\x04 \x01(\x0b\x32\x0e.v1.model.TextH\x00\x12$\n\x07numeric\x18\x05 \x01(\x0b\x32\x11.v1.model.NumericH\x00\x12+\n\x0bnumeric_set\x18\x11 \x01(\x0b\x32\x14.v1.model.NumericSetH\x00\x12\"\n\x06\x62itset\x18\x07 \x01(\x0b\x32\x10.v1.model.BitsetH\x00\x12\x1e\n\x04\x66ile\x18\x08 \x01(\x0b\x32\x0e.v1.model.FileH\x00\x12 \n\x05image\x18\t \x01(\x0b\x32\x0f.v1.model.ImageH\x00\x12+\n\x0bpoint_cloud\x18\n \x01(\x0b\x32\x14.v1.model.PointCloudH\x00\x12&\n\x08location\x18\x0b \x01(\x0b\x32\x12.v1.model.LocationH\x00\x12.\n\x0clocalization\x18\x0c \x01(\x0b\x32\x16.v1.model.LocalizationH\x00\x12\"\n\x06health\x18\r \x01(\x0b\x32\x10.v1.model.HealthH\x00\x12\x1e\n\x04json\x18\x0e \x01(\x0b\x32\x0e.v1.model.JsonH\x00\x12$\n\x07\x62\x61ttery\x18\x0f \x01(\x0b\x32\x11.v1.model.BatteryH\x00\x12 \n\x05video\x18\x10 \x01(\x0b\x32\x0f.v1.model.VideoH\x00\x12\x31\n\x0etransform_tree\x18\x12 \x01(\x0b\x32\x17.v1.model.TransformTreeH\x00\x12&\n\x08odometry\x18\x13 \x01(\x0b\x32\x12.v1.model.OdometryH\x00\x12\r\n\x05label\x18\x14 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04\x64\x61taJ\x04\x08\x06\x10\x07\"\xea\x02\n\x10\x43ontrolDatapoint\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\"\n\x06\x62itset\x18\x03 \x01(\x0b\x32\x10.v1.model.BitsetH\x00\x12 \n\x05twist\x18\x04 \x01(\x0b\x32\x0f.v1.model.TwistH\x00\x12#\n\x04pose\x18\x05 \x01(\x0b\x32\x13.v1.model.TransformH\x00\x12$\n\x07numeric\x18\x06 \x01(\x0b\x32\x11.v1.model.NumericH\x00\x12<\n\x14pose_with_covariance\x18\x07 \x01(\x0b\x32\x1c.v1.model.PoseWithCovarianceH\x00\x12 \n\x05point\x18\x08 \x01(\x0b\x32\x0f.v1.model.PointH\x00\x12\x1c\n\x03joy\x18\t \x01(\x0b\x32\r.v1.model.JoyH\x00\x12\x1c\n\x03\x62it\x18\n \x01(\x0b\x32\r.v1.model.BitH\x00\x42\x06\n\x04\x64\x61ta\"\x81\x02\n\x13GenericAPIDatapoint\x12\x0e\n\x06Method\x18\x01 \x01(\t\x12\x10\n\x08\x45ndpoint\x18\x02 \x01(\t\x12;\n\x07Headers\x18\x03 \x03(\x0b\x32*.v1.model.GenericAPIDatapoint.HeadersEntry\x12\x0c\n\x04\x42ody\x18\x04 \x01(\t\x12\x13\n\x0bIsRetryable\x18\x05 \x01(\x08\x12\x1a\n\x12RequireFormantAuth\x18\x06 \x01(\x08\x12\x1c\n\x14RetryableStatusCodes\x18\x07 \x03(\x03\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.datapoint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_DATAPOINT_TAGSENTRY']._loaded_options = None
  _globals['_DATAPOINT_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_GENERICAPIDATAPOINT_HEADERSENTRY']._loaded_options = None
  _globals['_GENERICAPIDATAPOINT_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_DATAPOINT']._serialized_start=223
  _globals['_DATAPOINT']._serialized_end=969
  _globals['_DATAPOINT_TAGSENTRY']._serialized_start=912
  _globals['_DATAPOINT_TAGSENTRY']._serialized_end=955
  _globals['_CONTROLDATAPOINT']._serialized_start=972
  _globals['_CONTROLDATAPOINT']._serialized_end=1334
  _globals['_GENERICAPIDATAPOINT']._serialized_start=1337
  _globals['_GENERICAPIDATAPOINT']._serialized_end=1594
  _globals['_GENERICAPIDATAPOINT_HEADERSENTRY']._serialized_start=1548
  _globals['_GENERICAPIDATAPOINT_HEADERSENTRY']._serialized_end=1594
# @@protoc_insertion_point(module_scope)



from . import Response, ScopeFilter, StreamCurrentValueListResponse, stream_current_value_controller_query
from formant.sdk.cloud.v2.src.resources.resources import Resources

class StreamCurrent(Resources):

    def query(self, scope_filter: ScopeFilter):
        """Gets you the current value of  a stream that has been configured to cache the current value"""
        client = self._get_client()
        response: Response[StreamCurrentValueListResponse] = stream_current_value_controller_query.sync_detailed(client=client, json_body=scope_filter)
        return response

    async def query_async(self, scope_filter: ScopeFilter):
        """Gets you the current value of  a stream that has been configured to cache the current value"""
        client = self._get_client()
        response: Response[StreamCurrentValueListResponse] = await stream_current_value_controller_query.asyncio_detailed(client=client, json_body=scope_filter)
        return response


from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="LoginRequestTags")


@attr.s(auto_attribs=True)
class LoginRequestTags:
    """
    Attributes:
        data (Union[Unset, Any]): Provide a tag set with the appropriate access level for devices, data and events.
        entities (Union[Unset, Any]): Provide a tag set with the appropriate access level for Formant entities (e.g.,
            views, command templates, users, teams).
    """

    data: Union[Unset, Any] = UNSET
    entities: Union[Unset, Any] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        data = self.data
        entities = self.entities

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data is not UNSET:
            field_dict["data"] = data
        if entities is not UNSET:
            field_dict["entities"] = entities

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        data = d.pop("data", UNSET)

        entities = d.pop("entities", UNSET)

        login_request_tags = cls(
            data=data,
            entities=entities,
        )

        login_request_tags.additional_properties = d
        return login_request_tags

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.geo_json_icon import GeoJsonIcon
    from ..models.geo_json_layer import GeoJsonLayer


T = TypeVar("T", bound="LocationModuleParameters")


@attr.s(auto_attribs=True)
class LocationModuleParameters:
    """
    Attributes:
        geo_json_layers (List['GeoJsonLayer']):
        geo_json_icons (List['GeoJsonIcon']):
    """

    geo_json_layers: List["GeoJsonLayer"]
    geo_json_icons: List["GeoJsonIcon"]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        geo_json_layers = []
        for geo_json_layers_item_data in self.geo_json_layers:
            geo_json_layers_item = geo_json_layers_item_data.to_dict()

            geo_json_layers.append(geo_json_layers_item)

        geo_json_icons = []
        for geo_json_icons_item_data in self.geo_json_icons:
            geo_json_icons_item = geo_json_icons_item_data.to_dict()

            geo_json_icons.append(geo_json_icons_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "geoJsonLayers": geo_json_layers,
                "geoJsonIcons": geo_json_icons,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.geo_json_icon import GeoJsonIcon
        from ..models.geo_json_layer import GeoJsonLayer

        d = src_dict.copy()
        geo_json_layers = []
        _geo_json_layers = d.pop("geoJsonLayers")
        for geo_json_layers_item_data in _geo_json_layers:
            geo_json_layers_item = GeoJsonLayer.from_dict(geo_json_layers_item_data)

            geo_json_layers.append(geo_json_layers_item)

        geo_json_icons = []
        _geo_json_icons = d.pop("geoJsonIcons")
        for geo_json_icons_item_data in _geo_json_icons:
            geo_json_icons_item = GeoJsonIcon.from_dict(geo_json_icons_item_data)

            geo_json_icons.append(geo_json_icons_item)

        location_module_parameters = cls(
            geo_json_layers=geo_json_layers,
            geo_json_icons=geo_json_icons,
        )

        location_module_parameters.additional_properties = d
        return location_module_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
